@@ -9,7 +9,7 @@ use Mojo::Redis::Database;
 use Mojo::Redis::PubSub;
 use Scalar::Util 'blessed';
 
-our $VERSION = '3.27';
+our $VERSION = '3.28';
 
 $ENV{MOJO_REDIS_URL} ||= 'redis://localhost:6379';
 
@@ -110,7 +110,7 @@ Mojo::Redis - Redis driver based on Mojo::IOLoop
   use Mojo::Redis;
   my $redis = Mojo::Redis->new;
   $redis->db->set(foo => 42);
-  $redis->expire(foo => 600);
+  $redis->db->expire(foo => 600);
   warn $redis->db->get('foo');
 
 =head2 Promises
